package com.ruoyi.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.SalesPromotion;

/**
 * SalesPromotionService接口
 * 
 * @author ruoyi
 * @date 2024-05-30
 */
public interface ISalesPromotionService extends IService<SalesPromotion>
{
    /**
     * 查询SalesPromotion
     * 
     * @param id SalesPromotion主键
     * @return SalesPromotion
     */
    public SalesPromotion selectSalesPromotionById(Long id);

    /**
     * 查询SalesPromotion列表
     * 
     * @param salesPromotion SalesPromotion
     * @return SalesPromotion集合
     */
    public List<SalesPromotion> selectSalesPromotionList(SalesPromotion salesPromotion);

    /**
     * 新增SalesPromotion
     * 
     * @param salesPromotion SalesPromotion
     * @return 结果
     */
    public int insertSalesPromotion(SalesPromotion salesPromotion);

    /**
     * 修改SalesPromotion
     * 
     * @param salesPromotion SalesPromotion
     * @return 结果
     */
    public int updateSalesPromotion(SalesPromotion salesPromotion);

    /**
     * 批量删除SalesPromotion
     * 
     * @param ids 需要删除的SalesPromotion主键集合
     * @return 结果
     */
    public int deleteSalesPromotionByIds(Long[] ids);

    /**
     * 删除SalesPromotion信息
     * 
     * @param id SalesPromotion主键
     * @return 结果
     */
    public int deleteSalesPromotionById(Long id);
}
